@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
-   Copyright (c) 2012 Daniel C. Bünzli. All rights reserved.
+   Copyright (c) 2012 The jsonm programmers. All rights reserved.
    Distributed under the ISC license, see terms at the end of the file.
-   jsonm v1.0.1
   ---------------------------------------------------------------------------*)
 
 (* Braced non-terminals in comments refer to RFC 4627 non-terminals. *)
@@ -593,7 +592,7 @@ let rec encode_ k e = function
 let rec encode_loop e = e.k <- encode_ encode_loop; `Ok
 let rec encode_json e = function  (* first [k] to start with [`Os] or [`As]. *)
 | `Lexeme (`Null | `Bool _ | `Float _ | `String _ | `As | `Os as l) ->
-    w_value false l encode_loop e
+    w_value ~in_obj:false l encode_loop e
 | `End | `Lexeme _ as v -> expect_json v
 | `White _ | `Comment _ as v -> encode_ (fun e -> e.k <- encode_json; `Ok) e v
 | `Await -> `Ok
@@ -629,7 +628,7 @@ module Uncut = struct
 end
 
 (*---------------------------------------------------------------------------
-   Copyright (c) 2012 Daniel C. Bünzli
+   Copyright (c) 2012 The jsonm programmers
 
    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted, provided that the above
